@@ -8,6 +8,7 @@ import (
 	"os/exec"
 	"path/filepath"
 	"runtime"
+	"sort"
 	"strconv"
 	"strings"
 	"time"
@@ -37,17 +38,17 @@ const defaultLightTheme = "tango"
 
 var versionString = "Should be set when building, please use build.sh to build"
 
-func printUsageEnvVar(envVarName string, description string, colors twin.ColorType) {
+func renderUsageEnvVar(envVarName string, description string, colors twin.ColorType) string {
 	value := os.Getenv(envVarName)
 	if len(value) == 0 {
-		return
+		return ""
 	}
 
 	style, err := m.TermcapToStyle(value)
 	if err != nil {
 		bold := twin.StyleDefault.WithAttr(twin.AttrBold).RenderUpdateFrom(twin.StyleDefault, colors)
 		notBold := twin.StyleDefault.RenderUpdateFrom(twin.StyleDefault.WithAttr(twin.AttrBold), colors)
-		fmt.Printf("  %s (%s): %s %s<- Error: %v%s\n",
+		return fmt.Sprintf("  %s (%s): %s %s<- Error: %v%s\n",
 			envVarName,
 			description,
 			strings.ReplaceAll(value, "\x1b", "ESC"),
@@ -55,18 +56,62 @@ func printUsageEnvVar(envVarName string, description string, colors twin.ColorTy
 			err,
 			notBold,
 		)
-		return
 	}
 
 	prefix := style.RenderUpdateFrom(twin.StyleDefault, colors)
 	suffix := twin.StyleDefault.RenderUpdateFrom(style, colors)
-	fmt.Printf("  %s (%s): %s\n",
+	return fmt.Sprintf("  %s (%s): %s\n",
 		envVarName,
 		description,
 		prefix+strings.ReplaceAll(value, "\x1b", "ESC")+suffix,
 	)
 }
 
+func renderPagerEnvVar(name string, colors twin.ColorType) string {
+	bold := twin.StyleDefault.WithAttr(twin.AttrBold).RenderUpdateFrom(twin.StyleDefault, colors)
+	notBold := twin.StyleDefault.RenderUpdateFrom(twin.StyleDefault.WithAttr(twin.AttrBold), colors)
+
+	value, isSet := os.LookupEnv(name)
+	if value == "" {
+		what := "unset"
+		if isSet {
+			what = "empty"
+		}
+
+		return fmt.Sprintf("  %s is %s %s<- Should be %s%s\n",
+			name,
+			what,
+			bold,
+			getMoarPath(),
+			notBold,
+		)
+	}
+
+	absMoarPath, err := absLookPath(os.Args[0])
+	if err != nil {
+		log.Warn("Unable to find absolute moar path: ", err)
+		return ""
+	}
+
+	absEnvValue, err := absLookPath(value)
+	if err != nil {
+		// This can happen if this is set to some outdated value
+		absEnvValue = value
+	}
+
+	if absEnvValue == absMoarPath {
+		return fmt.Sprintf("  %s=%s\n", name, value)
+	}
+
+	return fmt.Sprintf("  %s=%s %s<- Should be %s%s\n",
+		name,
+		value,
+		bold,
+		getMoarPath(),
+		notBold,
+	)
+}
+
 func printCommandline(output io.Writer) {
 	fmt.Fprintln(output, "Commandline: moar", strings.Join(os.Args[1:], " "))
 	fmt.Fprintf(output, "Environment: MOAR=\"%v\"\n", os.Getenv("MOAR"))
@@ -109,9 +154,38 @@ func printUsage(flagSet *flag.FlagSet, colors twin.ColorType) {
 		fmt.Printf("  Current setting: MOAR=\"%s\"\n", moarEnv)
 	}
 
-	printUsageEnvVar("LESS_TERMCAP_md", "man page bold style", colors)
-	printUsageEnvVar("LESS_TERMCAP_us", "man page underline style", colors)
-	printUsageEnvVar("LESS_TERMCAP_so", "search hits and footer style", colors)
+	envSection := ""
+	envSection += renderUsageEnvVar("LESS_TERMCAP_md", "man page bold style", colors)
+	envSection += renderUsageEnvVar("LESS_TERMCAP_us", "man page underline style", colors)
+	envSection += renderUsageEnvVar("LESS_TERMCAP_so", "search hits and footer style", colors)
+
+	envSection += renderPagerEnvVar("PAGER", colors)
+	envVars := os.Environ()
+	sort.Strings(envVars)
+	for _, env := range envVars {
+		split := strings.SplitN(env, "=", 2)
+		if len(split) != 2 {
+			continue
+		}
+
+		name := split[0]
+		if name == "PAGER" {
+			// Already done above
+			continue
+		}
+		if !strings.HasSuffix(name, "PAGER") {
+			continue
+		}
+
+		envSection += renderPagerEnvVar(name, colors)
+	}
+
+	if envSection != "" {
+		fmt.Println()
+
+		// Not Println since the section already ends with a newline
+		fmt.Print(envSection)
+	}
 
 	// Requested here: https://github.com/walles/moar/issues/170#issuecomment-1891154661
 	manroffopt := os.Getenv("MANROFFOPT")
@@ -603,6 +677,9 @@ func pagerFromArgs(
 				screen.Events() <- event
 			}
 
+		// The worst number I have measured was around 15ms, in GNOME Terminal
+		// running inside of VirtualBox. 3x that should be enough for everyone
+		// (TM).
 		case <-time.After(50 * time.Millisecond):
 			log.Debug("Terminal background color still not detected after ", time.Since(t0), ", giving up")
 		}
